mod common;

pub mod bash;
pub mod fish;
pub mod pwsh;
pub mod zsh;
pub use common::*;
